---
name: Feature request
about: Please only raise a feature request if you've been advised to do so after discussion.
  Thanks!
title: ''
labels: enhancement
assignees: ''

---

## Description of feature request

## Checklist

- [ ] Raised initially as discussion #...
- [ ] This cannot be dealt with as a third party library. (We prefer new functionality to be in the form of third party libraries where feasible.)
- [ ] I have reduced the issue to the simplest possible case.
